<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation>config.pyのエラー:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation>pluginのエラー:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation>ファイルはロードできません.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation>ファイルのフォーマットは読めません.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation>ファイルがセーブできません.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation>XMLは読み込みできません:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation>エンコーディングが読めません。</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation>この行目に答えが行方不明:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation>データベースをロードすることができません。
TMPファイルを使っています。</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>メモジーン</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation>ファイルがある:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation>&amp;上書きする</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;キャンセル</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation>同じカードを削除しました: </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation>この質問は二つ以上答えがあります:
</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;結合して編集する</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation>&amp;結合しない</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation>終わりました!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation>このカードはまだ覚えっていません。</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation>「０」みたく、だけどどんどんと慣れ親しんでいきます。.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation>　 今からあまり見せない方がいい。</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation>あなたは今このカードのことを記憶しました。,</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation>そしておそらく数日は覚えているでしょう。.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation>あなたはこのカードのことを完全に忘れてしまいました。</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation>かろうじて、正解。休止期間はあまりにも長すぎます。.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation>かなりの努力をして正解。（とても困難）.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation>　休止期間はおそらく長すぎます。</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation>いくつかの努力をしての正解。（そのとうり）.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation>　休止期間はおそらく正しい。</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation>何の困難も無く正解。この休止期間は</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation>おそらくとても短い。(簡単すぎます）.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>メモジーン</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>著者: Peter Bienstman

</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.sourceforge.net
</source>
        <translation type="obsolete">サイト: http://mnemosyne-proj.sourceforge.net
</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation>ウェブサイト：　http://mnemosyne-proj.org
</translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>メモジーンについて</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>カテゴリーを選択する</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>カテゴリーを選択してください:</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>どれも選択しない</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>すべてを選択</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;キャンセル</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;デフォルト&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>メモジーン</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>このカードを消してもよろしいですか?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;はい</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;いいえ</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>質問:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答え:</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>書形:</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>訳す:</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>このカードはもうデータベースに入っています.</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>同じカードを追加しませんでした。</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>この質問は</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation>　二つい以上答えがあります:
</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;結合して編集する</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>&amp;このままで追加</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>&amp;追加しない</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>カードを追加する</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>カテゴリー:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>質問:</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>発音:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答え:</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>&amp;逆カード（答え・質問順番）も追加する</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>最初のグレード:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>まだ覚えっていません。あるいは、忘れました.</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>「０」みたく、だけどどんどんと慣れ親しんでいきます。.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>覚えっています。たぶん2、3日覚えられるでしょう.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>かなりの努力をして正解。（とても困難）</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>いくつかの努力をしての正解。（そのとうり）.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>何の困難も無く正解。(簡単すぎます）.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>質問と答えを記入して、最初のグレードを選択する.</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">&amp;プレービュー</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;閉じる</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>プレービュー</translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>カテゴリーを変える</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>カテゴリー:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;キャンセル</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>メモジーンの設定</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>更なる情報を得るためには、マウスをボタンの上にとどめてください。</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>表示設定</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>質問・答えのフォントを選ぶ</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>質問と解答を表示するには使用フォントを選ぶ</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>リストフォントを選ぶ</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>カードデータベースに入っているカードの一覧を表示するには使用フォントを選ぶ</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>ラテン語ではない文字の容量を</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>時々英語意外の言葉は読みにくいので、ここで英語意外の文字を調整するのができる</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>X点によって増やす</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>匿名ログ設定</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>匿名データをアップロード</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>暗記研究のために匿名データをアップロードする</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>まったく同じカードの対応設定</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>新しいカードを記入する時、まったく同じカードがあるかどうかチェックする</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>違うカテゴリーにまったく同じカードを認める</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>カードの復讐設定</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to learn at once:</source>
        <translation type="obsolete">グレード０カードの枚数の同時習得:</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>注意：ただしい、これはグレード０カードの一日中の復讐できる枚数ではない。*</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>デフォルト</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;キャンセル</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation>新しいカードを無作為順番で習う</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>カードを編集する</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>カテゴリー:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>質問:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答え:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;プレービュー</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;キャンセル</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>少々お待ちください…</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;編集</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;プレービュー</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>&amp;逆も追加する</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>統&amp;計</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;消す</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>&amp;カテゴリーを変える</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>&amp;逆も追加する</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>逆もこれらのカードに追加しますか?</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>逆もこのカードに追加しますか?</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>メモジーン</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>
逆すがでに存在している場合は、ここで同じカードを作成することがあるので、直後に「同じカードを削除する」 を実行します　</translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation></translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;はい</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;いいえ</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>評価:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>やさしさ:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>何回見せた:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>何回忘れた:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>復習した日から何日:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>もう一度復習する日まで何日:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>このカードを消してもよろしいですか?</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>このカードを消してもよろしいですか?</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>入力された文は見つかりません。</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>&amp;Find again</translation>
    </message>
    <message>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Find</translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>質問</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>答え</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>カテゴリー</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>全部のカードを編集</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;探す</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>カードを編集するには、右クリックしてください。</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;閉じる</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation>Alt+F</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>全部のファイル　(*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>エクスポート</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>ファイルにエクスポート</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>ファイルのフォーマット:</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>エクスポートのファイル:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;見る</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>エクスポートをするカテゴリー:</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>&amp;すべてを選択</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>学習したデータをリセットする</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;キャンセル</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;デフォルト&gt;</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>全部のファイル　(*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>インポート</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>ファイルからインポート</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>ファイルのフォーマット:</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>ファイルからインポート:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;見る</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>カテゴリーがないカードをこのカテゴリーに入れる:</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>注： 全カードが現在使用中のデータベースに書き込まれます。</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>学習したデータをリセットする</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;キャンセル</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation>メモジーンデータベース(*.mem)</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新しいデータベース</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>少々お待ちください…</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>メモジーン</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation>このカードを消してもよろしいですか?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;はい</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;いいえ</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation>次は　</translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation>日の後。 </translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation>次：今日。</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation>次：明日。</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation>次は　</translation>
    </message>
    <message>
        <source> days.</source>
        <translation>　日の後。</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>質問:</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;デフォルト&gt;</translation>
    </message>
    <message>
        <source>Show &amp;answer</source>
        <translation type="obsolete">&amp;答えを表示する</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation>カードをスケジュールより早く復習する（おすすめではない）</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation>次の復讐のため何日間を選びなさい:</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>グレード:</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation>今日のカード: </translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation>まだ覚えっていないカード: </translation>
    </message>
    <message>
        <source>All: </source>
        <translation>全部のカード: </translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>答えを表示</translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>メモジーン</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>質問:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答え:</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>答えを表示</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>グレード:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;新しいデータベース</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;データベースを開く...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;セーブ</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>&amp;別名で保存する...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;閉じる</translation>
    </message>
    <message>
        <source>About</source>
        <translation>について</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;について</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>カードを追加する</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>&amp;カードを追加する</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>&amp;カテゴリーを選択する</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>カードのデータベースを編集する</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>&amp;カードのデータベースを編集する</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;インポート</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;エクスポート</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>&amp;ツールバーを表示する</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>このカードを編集する</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>&amp;このカードを編集する</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>このカードを消す</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>&amp;このカードを消す</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>&amp;まったく同じカードを削除する</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>&amp;メモジーンの設定</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>初めに</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>&amp;初めに</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>Down, Down</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Space</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>統計を表示する</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>&amp;統計を表示する</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>今日のヒント</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>&amp;今日のヒント</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>メーンツールバー(メモジーン)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;ファイル</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>&amp;カードのデータベース</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;設定</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;ヘルプ</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;デフォルト&gt;</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>質問:</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>カードをプレービュー</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>質問:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答え:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>初めに</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>ようこそ！

わたしの名前はMnemosyne、ギリシャ神話の記憶の女神の名前からとった名前です。

私はあなたが簡単におぼえることができて、すぐに思い出せるようにしてあげることができます。あなたが、もう良く知っているカードばかりに時間を取られないようにして、あなたが一番忘れがちなカードに集中できるお手伝いをします。

私がどんな質問をいつするかを決めるので、あなたはどれだけ答えを覚えていたかを採点してグレードを付けてください。

では、それらのグレードの意味を見てみましょう。.</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>グレードの紹介</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>グレードは0から5の範囲です。

あなたがまだ答えを知っていないか、またはあなたがそれを忘れたなら、グレード0と1は使用されています。 グレード1があるカードは、グレード0で1よりなじみ深くなり始めていて、よりしばしば繰り返されるでしょう。

私は、あなたがグレード2以上をそれらに与えるまであなたにこれらの質問をし続けるつもりです。 グレード2は、あなたが、少なくとも1日間か2日間カードを覚えていることができると思うのを意味します。 それは短くて長い用語メモリの間の変遷に合図します。

私はいつかの将来の期日にこのカードの計画をするつもりです、完全にそれを忘れるというわけではなくて。(その時、私は、あなたが何らかの努力でまだそれを覚えていることができると思います)。 学習過程に、これは最も効率的です。 </translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>グレード０ー２</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>もし私が同じ質問をすぐに出しすぎて、あなたが即座に回答できちゃった場合は「５」を付けてください。その場合には、私は同じ質問は当分しないことにします。

もし、私がいま出した質問を、あなたが覚えていたけど、ちょっと回答に苦労した場合は「４」を付けてください。

でも、私がだした質問に答えるのに、とっても苦労して、前回同じ質問をしてから時間がたちすぎているとおもったらそのカードは「３」にしてください。

もしそのカードの質問にこたえられなかったら、評価は０か１です。その場合は、私はあなたがその質問の答えをしばらく覚えていることができるようになるまでなんども質問を続けます。.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>グレード３ー５</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>あなたのレビューの統計は詳細に記録しています。

お望みなら、その記録を、匿名で、ホスト側にアップロードして、分析していかがでしょうか。
そうしますと、あなたのレビューが、長期記憶に関する科学的研究に資することにもなります。

もしあなたのレビューを匿名でアップロードすることをお望みでないなら、下記のボックスのチェックマークをオフにしてください。</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>匿名データをアップロード</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>(いつでも「メモジーンの設定」で変えることができます.)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>統計</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation>では、始めましょう！
&lt;p&gt;
新しいカードを追加するには、左上にある「プラス」サインがついたアイコンをクリックしてください。
&lt;p&gt;
保存する心配はありません。私が自動的にします。
&lt;p&gt;
良い結果のために、毎日復習することをお勧めましす。
&lt;p&gt;
さらなる資料についてはこちらをご覧ください：http://www.mnemosyne-proj.org
&lt;p&gt;
勉強楽しんでくださいね!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>準備OK</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>&amp;イメージを挿入する</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>&amp;音を挿入する</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>&amp;3面インプット</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>写真のファイル</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>イメージを挿入する</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>音のファイル</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>音を挿入する</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation>今度復習する予定のカード:
</translation>
    </message>
    <message>
        <source>In</source>
        <translation></translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>日:</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>カードのグレードの枚数: 
</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>グレード</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation>カードが選択されていない.</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>グレード:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>やさしさ:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>何回見せた:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>何回忘れた:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>復習した日から何日:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>もう一度復習する日まで何日:</translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>カテゴリー</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>カード</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>統計</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>スケジュール</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>グレード</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>カテゴリー</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation>選択されたカード</translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>毎日カードの復習をしたほうがおすすめです.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>もし、二三日復習しなかったら、無理しないでください。できるだけカードを復習して、その後自動的にメモジーンが残っているカードを延期する。</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>毎日何枚カードを習うのは自分で決めることです.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>つまり、毎日復習を頑張ってください。しかし、それができなかったら、心配しないでください。</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>グレード１のカードはグレード０のカードとは異なります。現れる頻度がグレード０のものより少ないのです。
また、グレード１のカードには、「グレード０カードの枚数の同時習得」設定用外です。</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>キーボードのショートカットを使って復習ができます。
Enter、Return, Spaceはデフォルト動作（初期設定値への動作）を示しています（答えを示す または グレード４）
数字キーは成績をつけることに使用できます。</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>「カードのデータベースース」の「カテゴリーを選択する」で、勉強したいカテゴリーを選ぶことができます。」.</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>全部のカードをひとつのデータベースに入れ、カテゴリーで分けることをお勧めいたします。</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>いろんなフォーマットからカードをインポートすることができます。
タブ区切りのテキストファイル（.txt)や、スーパーメモファイルなど、その他いろいろ。</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>お持ちのワード又はエクセルのフォーマットのカードをメモジーンにインポートしたい場合は、いったん、ユニコード(UTF-8)キャラクターでカンマ区切りのテキストファイルにエクスポートするのがお勧めです.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>カードをプリントアウトする場合には、txt ファイルにエキスポートしてください。txtファイルは、好きなワープロでプリントすることができます。</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>自分のカードを他の人にシェアためには、XMLにエクスポートし、オプションで「学習したデータをリセットする」を選んでください。</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>「ラテン語ではない文字」の設定で英語と日本語の文字を違う大きさで表示することができます。</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>カードにイメージや音を入れることができます。 カード編集画面の質問・答え上で右クリックするとメニューが出ますのでご利用下さい。.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>音声、映像ファイルを媒体ディレクトリに保存されることをお勧めいたします。そうすれば、データを他のコンピュータで移送することが容易になります。.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>three-sidedカード（単語or熟語のつづり、発音、意味をワンセットにしたカード）を追加すると、2つの通常カードが生成されます。
ひとつは問題として（単語or熟語の）つづりを、解答として発音と意味を収録したもの、もうひとつは問題として意味を、解答としてつづりと発音を収録したものです。</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>簡単なHTMLのタグを使って好みのカード表示に変えることができます。</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>
Mnemosyneならば，LaTeXを使って，&lt;$&gt;x^2+y^2=z^2&lt;/$&gt;のような数学公式をレンダリングできます。(これには，LaTeXとdvipngをインストールしておく必要があります)</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>データのバックアップを取る最高の方法は、.mnemosyneディレクトリをコピーして、それを異なるドライブの方へ動かすことです。...</translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>USBキーからメモジーンを実行することができます。
USBキーに「C:\Program Files\Mnemosyne」をコピーしてください。
次に、USBキーの中で、ホームディレクトリからMnemosyneキーまでをmnemosyneディレクトリーにコピーしてください。</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>複数のコンピューターからメモジーンを利用される方には、Unisonという、個人データをシンクロさせる便利なツールがあります。 詳しくはメモジーンのウェブサイトをご覧ください。</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation> 「カードのデータベースを編集する」で、カラムのタイトルをクリックしてカテゴリーを出すことで、カードをソートすることができます。２回クリックすると、ソートの順番を変えることができます。</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>LaTeXを上手に使うため、メモジーンのウェブサイトにある&lt;$$&gt;...&lt;/$$&gt;タグと&lt;latex&gt;...&lt;/latex&gt;タグの説明をご覧ください。</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>config.ｐｙファイルでメモジーン設定よりカスタマイズすることができます。そして、pluginで他の機能を追加することができます.</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>今日のヒント</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;ご存知ですか...?&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>&amp;初めに「今日のヒント」を表示する</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;前の</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;次の</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;閉じる</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
</TS>
